@@ -359,7 +359,7 @@ capplet_build (void)
   startup_sel = gtk_tree_view_get_selection (startup_view);
   gtk_tree_selection_set_mode (startup_sel, GTK_SELECTION_SINGLE);
   renderer = gtk_cell_renderer_text_new ();
-  column = gtk_tree_view_column_new_with_attributes (_("Priority"), renderer, "text", 1, NULL);
+  column = gtk_tree_view_column_new_with_attributes (_("Order"), renderer, "text", 1, NULL);
   gtk_tree_view_append_column (startup_view, column);
   column = gtk_tree_view_column_new_with_attributes (_("Command"), renderer, "text", 2, NULL);
   gtk_tree_view_append_column (startup_view, column);
@@ -406,6 +406,7 @@ apply (void)
   session_properties_apply ();
 
   gtk_widget_set_sensitive (apply_button, FALSE);
+  state_dirty = FALSE;
 }
 
 
@@ -484,7 +485,7 @@ add_startup_cb (void)
    * away to a different capplet
    */
   dirty_cb ();
-  startup_list_add_dialog (&startup_list, &startup_command_dialog);
+  startup_list_add_dialog (&startup_list, &startup_command_dialog, capplet);
   update_gui ();
 }
 
@@ -497,7 +498,7 @@ edit_startup_cb (void)
    * away to a different capplet
    */
   dirty_cb ();
-  startup_list_edit_dialog (&startup_list, startup_store, startup_sel, &startup_command_dialog);
+  startup_list_edit_dialog (&startup_list, startup_store, startup_sel, &startup_command_dialog, capplet);
   update_gui ();
 }
 
@@ -561,7 +562,7 @@ add_session_cb(void)
    * away to a different capplet
    */
   dirty_cb ();
-  session_list_add_dialog (&session_list, &session_command_dialog);
+  session_list_add_dialog (&session_list, &session_command_dialog, capplet);
   update_gui ();
 }
 
@@ -578,7 +579,7 @@ edit_session_cb (void)
   dirty_cb ();
   if (!gtk_tree_selection_get_selected (sessions_sel, NULL, &iter)) return;
   gtk_tree_model_get (sessions_store, &iter, 0, &str, -1);
-  session_list_edit_dialog (&session_list, str, &hashed_sessions, &session_command_dialog);
+  session_list_edit_dialog (&session_list, str, &hashed_sessions, &session_command_dialog, capplet);
   update_gui ();
 }
 
